Welcome to Flask-Manifest's documentation!
==========================================

Coming soon.

Contents:

.. toctree::
   :maxdepth: 2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
